@@ -122,8 +122,9 @@ class Detector(object):
         d = self.location - det.location
         return float(d.dot(d)**0.5 / constants.c.value)
 
-    def antenna_pattern(self, right_ascension, declination, polarization, t_gps):
+    def antenna_pattern(self, right_ascension, declination, polarization, t_gps, polarization_type='tensor'):
         """Return the detector response.
+
         Parameters
         ----------
         right_ascension: float or numpy.ndarray
@@ -132,12 +133,15 @@ class Detector(object):
             The declination of the source
         polarization: float or numpy.ndarray
             The polarization angle of the source
+        polarization_type: string flag: Tensor, Vector or Scalar
+            The gravitational wave polarizations. Default: 'Tensor'
+
         Returns
         -------
-        fplus: float or numpy.ndarray
-            The plus polarization factor for this sky location / orientation
-        fcross: float or numpy.ndarray
-            The cross polarization factor for this sky location / orientation
+        fplus(default) or fx or fb : float or numpy.ndarray
+            The plus or vector-x or breathing polarization factor for this sky location / orientation
+        fcross(default) or fy or fl : float or numpy.ndarray
+            The cross or vector-y or longitudnal polarization factor for this sky location / orientation
         """
         if isinstance(t_gps, lal.LIGOTimeGPS):
             t_gps = float(t_gps)
@@ -161,16 +165,42 @@ class Detector(object):
         y1 =  sinpsi * cosgha + cospsi * singha * sindec
         y2 =  cospsi * cosdec
         y = np.array([y0, y1, y2])
+
         dy = self.response.dot(y)
 
-        if hasattr(dx, 'shape'):
-            fplus = (x * dx - y * dy).sum(axis=0)
-            fcross = (x * dy + y * dx).sum(axis=0)
-        else:
-            fplus = (x * dx - y * dy).sum()
-            fcross = (x * dy + y * dx).sum()
+        z0 = -cosdec * cosgha
+        z1 = cosdec * singha
+        z2 = -sindec
+        z = np.array([z0, z1, z2])
 
-        return fplus, fcross
+        dz = self.response.dot(z)
+
+        if polarization_type == 'tensor':
+            if hasattr(dx, 'shape'):
+                fplus = (x * dx - y * dy).sum(axis=0)
+                fcross = (x * dy + y * dx).sum(axis=0)
+            else:
+                fplus = (x * dx - y * dy).sum()
+                fcross = (x * dy + y * dx).sum()
+            return fplus, fcross
+
+        elif polarization_type == 'vector':
+            if hasattr(dx, 'shape'):
+                fx = (z * dx + x * dz).sum(axis=0)
+                fy = (z * dy + y * dz).sum(axis=0)
+            else:
+                fx = (z * dx + x * dz).sum()
+                fy = (z * dy + y * dz).sum()
+            return fx, fy
+
+        elif polarization_type == 'scalar':
+            if hasattr(dx, 'shape'):
+                fb = (x * dx + y * dy).sum(axis=0)
+                fl = (z * dz).sum(axis=0)
+            else:
+                fb = (x * dx + y * dy).sum()
+                fl = (z * dz).sum()
+            return fb, fl
 
     def time_delay_from_earth_center(self, right_ascension, declination, t_gps):
         """Return the time delay from the earth center
@@ -240,18 +270,82 @@ class Detector(object):
                                              declination,
                                              t_gps)
 
-    def project_wave(self, hp, hc, longitude, latitude, polarization):
+    def project_wave(self, hp, hc, ra, dec, polarization,
+                     method='lal',
+                     reference_time=None):
         """Return the strain of a waveform as measured by the detector.
         Apply the time shift for the given detector relative to the assumed
         geocentric frame and apply the antenna patterns to the plus and cross
         polarizations.
+
+        Parameters
+        ----------
+        hp: pycbc.types.TimeSeries
+            Plus polarization of the GW
+        hc: pycbc.types.TimeSeries
+            Cross polarization of the GW
+        ra: float
+            Right ascension of source location
+        dec: float
+            Declination of source location
+        polarization: float
+            Polarization angle of the source
+        method: {'lal', 'constant', 'vary_polarization'}
+            The method to use for projecting the polarizations into the
+            detector frame. Default is 'lal'.
+        reference_time: float, Optional
+            The time to use as, a reference for some methods of projection.
+            Used by 'constant' and 'vary_polarization' methods. Uses average
+            time if not provided.
         """
-        h_lal = lalsimulation.SimDetectorStrainREAL8TimeSeries(
-                hp.astype(np.float64).lal(), hc.astype(np.float64).lal(),
-                longitude, latitude, polarization, self.frDetector)
-        return TimeSeries(
-                h_lal.data.data, delta_t=h_lal.deltaT, epoch=h_lal.epoch,
-                dtype=np.float64, copy=False)
+        # The robust and most fefature rich method which includes
+        # time changing antenna patterns and doppler shifts due to the
+        # earth rotation and orbit
+        if method == 'lal':
+            h_lal = lalsimulation.SimDetectorStrainREAL8TimeSeries(
+                    hp.astype(np.float64).lal(), hc.astype(np.float64).lal(),
+                    ra, dec, polarization, self.frDetector)
+            ts = TimeSeries(
+                    h_lal.data.data, delta_t=h_lal.deltaT, epoch=h_lal.epoch,
+                    dtype=np.float64, copy=False)
+
+        # 'constant' assume fixed orientation relative to source over the
+        # duration of the signal, accurate for short duration signals
+        # 'fixed_polarization' applies only time changing orientation
+        # but no doppler corrections
+        elif method in ['constant', 'vary_polarization']:
+            if reference_time is not None:
+                rtime = reference_time
+            else:
+                # In many cases, one should set the reference time if using
+                # this method as we don't know where the signal is within
+                # the given time series. If not provided, we'll choose
+                # the midpoint time.
+                rtime = (float(hp.end_time) + float(hp.start_time)) / 2.0
+
+            if method == 'constant':
+                time = rtime
+            elif method == 'vary_polarization':
+                if (not isinstance(hp, TimeSeries) or
+                   not isinstance(hc, TimeSeries)):
+                    raise TypeError('Waveform polarizations must be given'
+                                    ' as time series for this method')
+
+                # this is more granular than needed, may be optimized later
+                # assume earth rotation in ~30 ms needed for earth ceneter
+                # to detector is completely negligible.
+                time = hp.sample_times.numpy()
+
+            fp, fc = self.antenna_pattern(ra, dec, polarization, time)
+            dt = self.time_delay_from_earth_center(ra, dec, rtime)
+            ts = fp * hp + fc * hc
+            ts.start_time = float(ts.start_time) + dt
+
+        # add in only the correction for the time variance in the polarization
+        # due to the earth's rotation, no doppler correction applied
+        else:
+            raise ValueError("Unkown projection method {}".format(method))
+        return ts
 
     def optimal_orientation(self, t_gps):
         """Return the optimal orientation in right ascension and declination
