@@ -24,6 +24,8 @@ from .analytic import (TestEggbox, TestNormal, TestRosenbrock, TestVolcano,
                        TestPrior)
 from .gaussian_noise import GaussianNoise
 from .marginalized_gaussian_noise import MarginalizedPhaseGaussianNoise
+from .marginalized_gaussian_noise import MarginalizedPolarization
+from .brute_marg import BruteParallelGaussianMarginalize
 from .single_template import SingleTemplate
 from .relbin import Relative
 
@@ -182,6 +184,8 @@ models = {_cls.name: _cls for _cls in (
     TestPrior,
     GaussianNoise,
     MarginalizedPhaseGaussianNoise,
+    MarginalizedPolarization,
+    BruteParallelGaussianMarginalize,
     SingleTemplate,
     Relative
 )}
