@@ -42,6 +42,7 @@ class PyCBCBank2HDFExecutable(Executable):
         node.new_output_file_opt(bank_file.segment, '.hdf', '--output-file')
         return node
 
+
 class PyCBCTrig2HDFExecutable(Executable):
     """Converts xml triggers to hdf format, grouped by template hash"""
 
@@ -54,6 +55,7 @@ class PyCBCTrig2HDFExecutable(Executable):
                                  '--output-file', use_tmp_subdirs=True)
         return node
 
+
 class PyCBCFitByTemplateExecutable(Executable):
     """Calculates values that describe the background distribution template by template"""
 
@@ -69,6 +71,7 @@ class PyCBCFitByTemplateExecutable(Executable):
         node.new_output_file_opt(trig_file.segment, '.hdf', '--output')
         return node
 
+
 class PyCBCFitOverParamExecutable(Executable):
     """Smooths the background distribution parameters over a continuous parameter"""
 
@@ -80,33 +83,10 @@ class PyCBCFitOverParamExecutable(Executable):
         node.new_output_file_opt(raw_fit_file.segment, '.hdf', '--output')
         return node
 
+
 class PyCBCFindCoincExecutable(Executable):
     """Find coinc triggers using a folded interval method"""
 
-    current_retention_level = Executable.ALL_TRIGGERS
-    file_input_options = ['--statistic-files']
-    def create_node(self, trig_files, bank_file, stat_files, veto_file,
-                    veto_name, template_str, tags=None):
-        if tags is None:
-            tags = []
-        segs = trig_files.get_times_covered_by_files()
-        seg = segments.segment(segs[0][0], segs[-1][1])
-        node = Node(self)
-        node.set_memory(10000)
-        node.add_input_opt('--template-bank', bank_file)
-        node.add_input_list_opt('--trigger-files', trig_files)
-        if len(stat_files) > 0:
-            node.add_input_list_opt('--statistic-files', stat_files)
-        if veto_file is not None:
-            node.add_input_opt('--veto-files', veto_file)
-            node.add_opt('--segment-name', veto_name)
-        node.add_opt('--template-fraction-range', template_str)
-        node.new_output_file_opt(seg, '.hdf', '--output-file', tags=tags)
-        return node
-
-class PyCBCFindMultiifoCoincExecutable(Executable):
-    """Find coinc triggers using a folded interval method"""
-
     current_retention_level = Executable.ALL_TRIGGERS
     file_input_options = ['--statistic-files']
     def create_node(self, trig_files, bank_file, stat_files, veto_file,
@@ -129,29 +109,10 @@ class PyCBCFindMultiifoCoincExecutable(Executable):
         node.new_output_file_opt(seg, '.hdf', '--output-file', tags=tags)
         return node
 
+
 class PyCBCStatMapExecutable(Executable):
     """Calculate FAP, IFAR, etc"""
 
-    current_retention_level = Executable.MERGED_TRIGGERS
-    def create_node(self, coinc_files, tags=None):
-        if tags is None:
-            tags = []
-        segs = coinc_files.get_times_covered_by_files()
-        seg = segments.segment(segs[0][0], segs[-1][1])
-
-        node = Node(self)
-        node.set_memory(5000)
-        if isinstance(coinc_files, list):
-            node.add_input_list_opt('--coinc-files', coinc_files)
-        else:
-            node.add_input_opt('--coinc-files', coinc_files)
-
-        node.new_output_file_opt(seg, '.hdf', '--output-file', tags=tags)
-        return node
-
-class PyCBCMultiifoStatMapExecutable(Executable):
-    """Calculate FAP, IFAR, etc"""
-
     current_retention_level = Executable.MERGED_TRIGGERS
     def create_node(self, coinc_files, ifos, tags=None):
         if tags is None:
@@ -160,13 +121,13 @@ class PyCBCMultiifoStatMapExecutable(Executable):
         seg = segments.segment(segs[0][0], segs[-1][1])
 
         node = Node(self)
-        node.set_memory(5000)
         node.add_input_list_opt('--coinc-files', coinc_files)
         node.add_opt('--ifos', ifos)
         node.new_output_file_opt(seg, '.hdf', '--output-file', tags=tags)
         return node
 
-class PyCBCMultiifoStatMapInjExecutable(Executable):
+
+class PyCBCStatMapInjExecutable(Executable):
     """Calculate FAP, IFAR, etc"""
 
     current_retention_level = Executable.MERGED_TRIGGERS
@@ -178,7 +139,6 @@ class PyCBCMultiifoStatMapInjExecutable(Executable):
         seg = segments.segment(segs[0][0], segs[-1][1])
 
         node = Node(self)
-        node.set_memory(5000)
         node.add_input_list_opt('--zero-lag-coincs', zerolag)
 
         if isinstance(full_data, list):
@@ -192,24 +152,6 @@ class PyCBCMultiifoStatMapInjExecutable(Executable):
         node.new_output_file_opt(seg, '.hdf', '--output-file', tags=tags)
         return node
 
-class PyCBCStatMapInjExecutable(Executable):
-    """Calculate FAP, IFAR, etc for injections"""
-
-    current_retention_level = Executable.MERGED_TRIGGERS
-    def create_node(self, zerolag, full_data, injfull, fullinj, tags=None):
-        if tags is None:
-            tags = []
-        segs = zerolag.get_times_covered_by_files()
-        seg = segments.segment(segs[0][0], segs[-1][1])
-
-        node = Node(self)
-        node.set_memory(5000)
-        node.add_input_list_opt('--zero-lag-coincs', zerolag)
-        node.add_input_list_opt('--full-data-background', full_data)
-        node.add_input_list_opt('--mixed-coincs-inj-full', injfull)
-        node.add_input_list_opt('--mixed-coincs-full-inj', fullinj)
-        node.new_output_file_opt(seg, '.hdf', '--output-file', tags=tags)
-        return node
 
 class PyCBCHDFInjFindExecutable(Executable):
     """Find injections in the hdf files output"""
@@ -228,6 +170,7 @@ class PyCBCHDFInjFindExecutable(Executable):
                                  '--output-file', tags=tags)
         return node
 
+
 class PyCBCDistributeBackgroundBins(Executable):
     """Distribute coinc files among different background bins"""
 
@@ -252,6 +195,7 @@ class PyCBCDistributeBackgroundBins(Executable):
         node.names = names
         return node
 
+
 class PyCBCCombineStatmap(Executable):
     """Combine coincs over different bins and apply trials factor"""
 
@@ -265,20 +209,15 @@ class PyCBCCombineStatmap(Executable):
                                  '--output-file', tags=tags)
         return node
 
-class PyCBCMultiifoCombineStatmap(PyCBCCombineStatmap):
-    """Combine coincs over different coinc types and apply trials factor"""
 
-    # same inputs and outputs as PyCBCCombineStatmap
-    current_retention_level = Executable.MERGED_TRIGGERS
-
-class PyCBCMultiifoAddStatmap(PyCBCMultiifoCombineStatmap):
+class PyCBCAddStatmap(PyCBCCombineStatmap):
     """Combine statmap files and add FARs over different coinc types"""
 
     current_retention_level = Executable.MERGED_TRIGGERS
     def create_node(self, statmap_files, background_files, tags=None):
         if tags is None:
             tags = []
-        node = super(PyCBCMultiifoAddStatmap, self).create_node(statmap_files,
+        node = super(PyCBCAddStatmap, self).create_node(statmap_files,
                                                             tags=tags)
         # Enforce upper case
         ctags = [t.upper() for t in (tags + self.tags)]
@@ -287,7 +226,8 @@ class PyCBCMultiifoAddStatmap(PyCBCMultiifoCombineStatmap):
 
         return node
 
-class PyCBCMultiifoExcludeZerolag(Executable):
+
+class PyCBCExcludeZerolag(Executable):
     """ Remove times of zerolag coincidences of all types from exclusive
         background """
     current_retention_level = Executable.MERGED_TRIGGERS
@@ -303,9 +243,11 @@ class PyCBCMultiifoExcludeZerolag(Executable):
 
         return node
 
+
 class MergeExecutable(Executable):
     current_retention_level = Executable.MERGED_TRIGGERS
 
+
 class CensorForeground(Executable):
     current_retention_level = Executable.MERGED_TRIGGERS
 
@@ -323,6 +265,7 @@ def make_foreground_censored_veto(workflow, bg_file, veto_file, veto_name,
     workflow += node
     return node.output_files[0]
 
+
 def merge_single_detector_hdf_files(workflow, bank_file, trigger_files, out_dir, tags=None):
     if tags is None:
         tags = []
@@ -338,6 +281,7 @@ def merge_single_detector_hdf_files(workflow, bank_file, trigger_files, out_dir,
         out += node.output_files
     return out
 
+
 def setup_trigger_fitting(workflow, insps, hdfbank, veto_file, veto_name,
                           output_dir=None, tags=None):
     if not workflow.cp.has_option('workflow-coincidence', 'do-trigger-fitting'):
@@ -365,6 +309,7 @@ def setup_trigger_fitting(workflow, insps, hdfbank, veto_file, veto_name,
             smoothed_fit_files += smooth_node.output_files
         return smoothed_fit_files
 
+
 def find_injections_in_hdf_coinc(workflow, inj_coinc_file, inj_xml_file,
                                  veto_file, veto_name, out_dir, tags=None):
     if tags is None:
@@ -377,6 +322,7 @@ def find_injections_in_hdf_coinc(workflow, inj_coinc_file, inj_xml_file,
     workflow += node
     return node.output_files[0]
 
+
 def convert_bank_to_hdf(workflow, xmlbank, out_dir, tags=None):
     """Return the template bank in hdf format"""
     if tags is None:
@@ -394,6 +340,7 @@ def convert_bank_to_hdf(workflow, xmlbank, out_dir, tags=None):
     workflow.add_node(bank2hdf_node)
     return bank2hdf_node.output_files
 
+
 def convert_trig_to_hdf(workflow, hdfbank, xml_trigger_files, out_dir, tags=None):
     """Return the list of hdf5 trigger files outputs"""
     if tags is None:
@@ -413,26 +360,28 @@ def convert_trig_to_hdf(workflow, hdfbank, xml_trigger_files, out_dir, tags=None
             trig_files += trig2hdf_node.output_files
     return trig_files
 
-def setup_multiifo_statmap(workflow, ifos, coinc_files, out_dir, tags=None):
+
+def setup_statmap(workflow, ifos, coinc_files, out_dir, tags=None):
     tags = [] if tags is None else tags
 
-    statmap_exe = PyCBCMultiifoStatMapExecutable(workflow.cp, 'multiifo_statmap',
-                                              ifos=ifos,
-                                              tags=tags, out_dir=out_dir)
+    statmap_exe = PyCBCStatMapExecutable(workflow.cp, 'statmap',
+                                         ifos=ifos,
+                                         tags=tags, out_dir=out_dir)
 
     ifolist = ' '.join(ifos)
     stat_node = statmap_exe.create_node(coinc_files, ifolist)
     workflow.add_node(stat_node)
     return stat_node.output_file
 
-def setup_multiifo_statmap_inj(workflow, ifos, coinc_files, background_file,
-                               out_dir, tags=None):
+
+def setup_statmap_inj(workflow, ifos, coinc_files, background_file,
+                      out_dir, tags=None):
     tags = [] if tags is None else tags
 
-    statmap_exe = PyCBCMultiifoStatMapInjExecutable(workflow.cp,
-                                                    'multiifo_statmap_inj',
-                                                    ifos=ifos,
-                                                    tags=tags, out_dir=out_dir)
+    statmap_exe = PyCBCStatMapInjExecutable(workflow.cp,
+                                            'statmap_inj',
+                                            ifos=ifos,
+                                            tags=tags, out_dir=out_dir)
 
     ifolist = ' '.join(ifos)
     stat_node = statmap_exe.create_node(FileList(coinc_files['injinj']),
@@ -443,240 +392,13 @@ def setup_multiifo_statmap_inj(workflow, ifos, coinc_files, background_file,
     workflow.add_node(stat_node)
     return stat_node.output_files[0]
 
-def setup_statmap(workflow, coinc_files, bank_file, out_dir, tags=None):
-    tags = [] if tags is None else tags
-    if workflow.cp.has_option_tags('workflow-coincidence', 'background-bins', tags):
-        return setup_background_bins(workflow, coinc_files, bank_file, out_dir, tags=tags)
-    else:
-        return setup_simple_statmap(workflow, coinc_files, out_dir, tags=tags)
-
-def setup_simple_statmap(workflow, coinc_files, out_dir, tags=None):
-    tags = [] if tags is None else tags
-
-    statmap_exe = PyCBCStatMapExecutable(workflow.cp, 'statmap',
-                                              ifos=workflow.ifos,
-                                              tags=tags, out_dir=out_dir)
-
-    stat_node = statmap_exe.create_node(coinc_files)
-    workflow.add_node(stat_node)
-    return stat_node.output_files[0], stat_node.output_files
-
-def setup_background_bins(workflow, coinc_files, bank_file, out_dir, tags=None):
-    tags = [] if tags is None else tags
-
-    bins_exe = PyCBCDistributeBackgroundBins(workflow.cp, 'distribute_background_bins',
-                                       ifos=workflow.ifos, tags=tags, out_dir=out_dir)
-
-    statmap_exe = PyCBCStatMapExecutable(workflow.cp, 'statmap',
-                                              ifos=workflow.ifos,
-                                              tags=tags, out_dir=out_dir)
-
-    cstat_exe = PyCBCCombineStatmap(workflow.cp, 'combine_statmap', ifos=workflow.ifos,
-                                    tags=tags, out_dir=out_dir)
-
-    background_bins = workflow.cp.get_opt_tags('workflow-coincidence', 'background-bins', tags).split(' ')
-    background_bins = [x for x in background_bins if x != '']
-    bins_node = bins_exe.create_node(coinc_files, bank_file, background_bins)
-    workflow += bins_node
-
-    statmap_files = FileList([])
-    for i, coinc_file in enumerate(bins_node.output_files):
-        statnode = statmap_exe.create_node(FileList([coinc_file]), tags=['BIN_%s' % i])
-        workflow += statnode
-        statmap_files.append(statnode.output_files[0])
-        statmap_files[i].bin_name = bins_node.names[i]
-
-    cstat_node = cstat_exe.create_node(statmap_files)
-    workflow += cstat_node
-
-    return cstat_node.output_files[0], statmap_files
-
-def setup_statmap_inj(workflow, coinc_files, background_file, bank_file,
-                      out_dir, tags=None):
-    tags = [] if tags is None else tags
-    if workflow.cp.has_option_tags('workflow-coincidence',
-                                   'background-bins', tags):
-        return setup_background_bins_inj(workflow, coinc_files,
-                                         background_file, bank_file, out_dir,
-                                         tags=tags)
-    else:
-        return setup_simple_statmap_inj(workflow, coinc_files, background_file,
-                                        out_dir, tags=tags)
-
-def setup_simple_statmap_inj(workflow, coinc_files, background_file, out_dir,
-                             tags=None):
-    tags = [] if tags is None else tags
-
-    statmap_exe = PyCBCStatMapInjExecutable(workflow.cp, 'statmap_inj',
-                                            ifos=workflow.ifos,
-                                            tags=tags, out_dir=out_dir)
-
-    stat_node = statmap_exe.create_node(FileList(coinc_files['injinj']),
-                                        background_file,
-                                        FileList(coinc_files['injfull']),
-                                        FileList(coinc_files['fullinj']))
-    workflow.add_node(stat_node)
-    return stat_node.output_files[0]
-
-def setup_background_bins_inj(workflow, coinc_files, background_file,
-                              bank_file, out_dir, tags=None):
-    tags = [] if tags is None else tags
-
-    bins_exe = PyCBCDistributeBackgroundBins(workflow.cp,
-                                             'distribute_background_bins',
-                                             ifos=workflow.ifos, tags=tags,
-                                             out_dir=out_dir)
-
-    statmap_exe = PyCBCStatMapInjExecutable(workflow.cp, 'statmap_inj',
-                                            ifos=workflow.ifos, tags=tags,
-                                            out_dir=out_dir)
-
-    cstat_exe = PyCBCCombineStatmap(workflow.cp, 'combine_statmap',
-                                    ifos=workflow.ifos, tags=tags,
-                                    out_dir=out_dir)
-
-    background_bins = workflow.cp.get_opt_tags('workflow-coincidence',
-                                               'background-bins',
-                                               tags).split(' ')
-    background_bins = [x for x in background_bins if x != '']
-
-    for inj_type in ['injinj', 'injfull', 'fullinj']:
-        bins_node = bins_exe.create_node(FileList(coinc_files[inj_type]),
-                                         bank_file, background_bins,
-                                         tags=[inj_type])
-        workflow += bins_node
-        coinc_files[inj_type] = bins_node.output_files
-
-    statmap_files = FileList([])
-    for i in range(len(background_bins)):
-        statnode = statmap_exe.create_node(
-            FileList([coinc_files['injinj'][i]]),
-            FileList([background_file[i]]),
-            FileList([coinc_files['injfull'][i]]),
-            FileList([coinc_files['fullinj'][i]]),
-            tags=['BIN_%s' % i]
-        )
-        workflow += statnode
-        statmap_files.append(statnode.output_files[0])
-
-    cstat_node = cstat_exe.create_node(statmap_files)
-    workflow += cstat_node
-
-    return cstat_node.output_files[0]
 
 def setup_interval_coinc_inj(workflow, hdfbank, full_data_trig_files,
-                             inj_trig_files, stat_files, background_file,
-                             veto_file, veto_name, out_dir, tags=None):
+                             inj_trig_files, stat_files,
+                             background_file, veto_file, veto_name,
+                             out_dir, pivot_ifo, fixed_ifo, tags=None):
     """
-    Set up exact match coincidence and background estimation
-
-    This function sets up exact match coincidence and background estimation
-    using a folded interval technique.
-    """
-    if tags is None:
-        tags = []
-    make_analysis_dir(out_dir)
-    logging.info('Setting up coincidence for injection')
-
-    if len(hdfbank) > 1:
-        raise ValueError('This coincidence method only supports a '
-                         'pregenerated template bank')
-    hdfbank = hdfbank[0]
-
-    if len(workflow.ifos) > 2:
-        err_msg = 'This coincidence method only supports two-ifo searches'
-        raise ValueError(err_msg)
-
-    # Wall time knob and memory knob
-    factor = int(workflow.cp.get_opt_tags('workflow-coincidence',
-                                          'parallelization-factor', tags))
-
-    ffiles = {}
-    ifiles = {}
-    for ifo, ffi in zip(*full_data_trig_files.categorize_by_attr('ifo')):
-        ffiles[ifo] = ffi[0]
-    ifos, files = inj_trig_files.categorize_by_attr('ifo')  # ifos list is used later
-    for ifo, ifi in zip(ifos, files):
-        ifiles[ifo] = ifi[0]
-    ifo0, ifo1 = ifos[0], ifos[1]
-    combo = [(FileList([ifiles[ifo0], ifiles[ifo1]]), "injinj"),
-             (FileList([ifiles[ifo0], ffiles[ifo1]]), "injfull"),
-             (FileList([ifiles[ifo1], ffiles[ifo0]]), "fullinj"),
-            ]
-    bg_files = {'injinj':[], 'injfull':[], 'fullinj':[]}
-
-    for trig_files, ctag in combo:
-        findcoinc_exe = PyCBCFindCoincExecutable(workflow.cp, 'coinc',
-                                                 ifos=workflow.ifos,
-                                                 tags=tags + [ctag],
-                                                 out_dir=out_dir)
-        for i in range(factor):
-            group_str = '%s/%s' % (i, factor)
-            coinc_node = findcoinc_exe.create_node(trig_files, hdfbank,
-                                                   stat_files,
-                                                   veto_file, veto_name,
-                                                   group_str,
-                                                   tags=["JOB"+str(i)])
-            bg_files[ctag] += coinc_node.output_files
-            workflow.add_node(coinc_node)
-
-    return setup_statmap_inj(workflow, bg_files, background_file, hdfbank,
-                             out_dir, tags=tags)
-
-def setup_interval_coinc(workflow, hdfbank, trig_files, stat_files,
-                         veto_files, veto_names, out_dir, tags=None):
-    """
-    This function sets up exact match coincidence and background estimation
-
-    using a folded interval technique.
-    """
-    if tags is None:
-        tags = []
-    make_analysis_dir(out_dir)
-    logging.info('Setting up coincidence')
-
-    if len(hdfbank) != 1:
-        raise ValueError('Must use exactly 1 bank file for this coincidence '
-                         'method, I got %i !' % len(hdfbank))
-    hdfbank = hdfbank[0]
-
-    if len(workflow.ifos) > 2:
-        raise ValueError('This coincidence method only supports two-ifo '
-                         'searches')
-
-    findcoinc_exe = PyCBCFindCoincExecutable(workflow.cp, 'coinc',
-                                             ifos=workflow.ifos,
-                                             tags=tags, out_dir=out_dir)
-
-    # Wall time knob and memory knob
-    factor = int(workflow.cp.get_opt_tags('workflow-coincidence',
-                                          'parallelization-factor', tags))
-
-    statmap_files = []
-    for veto_file, veto_name in zip(veto_files, veto_names):
-        bg_files = FileList()
-        for i in range(factor):
-            group_str = '%s/%s' % (i, factor)
-            coinc_node = findcoinc_exe.create_node(trig_files, hdfbank,
-                                                   stat_files,
-                                                   veto_file, veto_name,
-                                                   group_str,
-                                                   tags=[veto_name, str(i)])
-            bg_files += coinc_node.output_files
-            workflow.add_node(coinc_node)
-
-        statmap_files += [setup_statmap(workflow, bg_files, hdfbank, out_dir,
-                                        tags=tags + [veto_name])]
-
-    logging.info('...leaving coincidence ')
-    return statmap_files
-
-def setup_multiifo_interval_coinc_inj(workflow, hdfbank, full_data_trig_files,
-                                      inj_trig_files, stat_files,
-                                      background_file, veto_file, veto_name,
-                                      out_dir, pivot_ifo, fixed_ifo, tags=None):
-    """
-    This function sets up exact match multiifo coincidence for injections
+    This function sets up exact match coincidence for injections
     """
     if tags is None:
         tags = []
@@ -716,11 +438,11 @@ def setup_multiifo_interval_coinc_inj(workflow, hdfbank, full_data_trig_files,
     bg_files = {'injinj':[], 'injfull':[], 'fullinj':[]}
 
     for trig_files, ctag in combo:
-        findcoinc_exe = PyCBCFindMultiifoCoincExecutable(workflow.cp,
-                                                         'multiifo_coinc',
-                                                         ifos=ifiles.keys(),
-                                                         tags=tags + [ctag],
-                                                         out_dir=out_dir)
+        findcoinc_exe = PyCBCFindCoincExecutable(workflow.cp,
+                                                 'coinc',
+                                                 ifos=ifiles.keys(),
+                                                 tags=tags + [ctag],
+                                                 out_dir=out_dir)
         for i in range(factor):
             group_str = '%s/%s' % (i, factor)
             coinc_node = findcoinc_exe.create_node(trig_files, hdfbank,
@@ -736,15 +458,16 @@ def setup_multiifo_interval_coinc_inj(workflow, hdfbank, full_data_trig_files,
 
     logging.info('...leaving coincidence for injections')
 
-    return setup_multiifo_statmap_inj(workflow, ifiles.keys(), bg_files,
-                                      background_file, out_dir,
-                                      tags=tags + [veto_name])
+    return setup_statmap_inj(workflow, ifiles.keys(), bg_files,
+                             background_file, out_dir,
+                             tags=tags + [veto_name])
 
-def setup_multiifo_interval_coinc(workflow, hdfbank, trig_files, stat_files,
-                                  veto_file, veto_name, out_dir, pivot_ifo,
-                                  fixed_ifo, tags=None):
+
+def setup_interval_coinc(workflow, hdfbank, trig_files, stat_files,
+                         veto_file, veto_name, out_dir, pivot_ifo,
+                         fixed_ifo, tags=None):
     """
-    This function sets up exact match multiifo coincidence
+    This function sets up exact match coincidence
     """
     if tags is None:
         tags = []
@@ -752,7 +475,7 @@ def setup_multiifo_interval_coinc(workflow, hdfbank, trig_files, stat_files,
     logging.info('Setting up coincidence')
 
     ifos, _ = trig_files.categorize_by_attr('ifo')
-    findcoinc_exe = PyCBCFindMultiifoCoincExecutable(workflow.cp, 'multiifo_coinc',
+    findcoinc_exe = PyCBCFindCoincExecutable(workflow.cp, 'coinc',
                                              ifos=ifos,
                                              tags=tags, out_dir=out_dir)
 
@@ -775,13 +498,13 @@ def setup_multiifo_interval_coinc(workflow, hdfbank, trig_files, stat_files,
         bg_files += coinc_node.output_files
         workflow.add_node(coinc_node)
 
-    statmap_files = setup_multiifo_statmap(workflow, ifos, bg_files,
-                                           out_dir,
-                                           tags=tags)
+    statmap_files = setup_statmap(workflow, ifos, bg_files,
+                                  out_dir, tags=tags)
 
     logging.info('...leaving coincidence ')
     return statmap_files
 
+
 def select_files_by_ifo_combination(ifocomb, insps):
     """
     This function selects single-detector files ('insps') for a given ifo combination
@@ -793,6 +516,7 @@ def select_files_by_ifo_combination(ifocomb, insps):
 
     return inspcomb
 
+
 def get_ordered_ifo_list(ifocomb, ifo_ids):
     """
     This function sorts the combination of ifos (ifocomb) based on the given
@@ -807,40 +531,42 @@ def get_ordered_ifo_list(ifocomb, ifo_ids):
 
     return pivot_ifo, fixed_ifo, ''.join(ordered_ifo_list)
 
-def setup_multiifo_combine_statmap(workflow, final_bg_file_list, bg_file_list,
-                                   out_dir, tags=None):
+
+def setup_combine_statmap(workflow, final_bg_file_list, bg_file_list,
+                          out_dir, tags=None):
     """
-    Combine the multiifo statmap files into one background file
+    Combine the statmap files into one background file
     """
     if tags is None:
         tags = []
     make_analysis_dir(out_dir)
-    logging.info('Setting up multiifo combine statmap')
+    logging.info('Setting up combine statmap')
 
     cstat_exe_name = os.path.basename(workflow.cp.get("executables",
                                                       "combine_statmap"))
-    if cstat_exe_name == 'pycbc_multiifo_combine_statmap':
-        cstat_class = PyCBCMultiifoCombineStatmap
-    elif cstat_exe_name == 'pycbc_multiifo_add_statmap':
-        cstat_class = PyCBCMultiifoAddStatmap
+    if cstat_exe_name == 'pycbc_combine_statmap':
+        cstat_class = PyCBCCombineStatmap
+    elif cstat_exe_name == 'pycbc_add_statmap':
+        cstat_class = PyCBCAddStatmap
     else:
         raise NotImplementedError('executable should be '
-            'pycbc_multiifo_combine_statmap or pycbc_multiifo_add_statmap')
+            'pycbc_combine_statmap or pycbc_add_statmap')
 
     cstat_exe = cstat_class(workflow.cp, 'combine_statmap', ifos=workflow.ifos,
                             tags=tags, out_dir=out_dir)
 
-    if cstat_exe_name == 'pycbc_multiifo_combine_statmap':
+    if cstat_exe_name == 'pycbc_combine_statmap':
         combine_statmap_node = cstat_exe.create_node(final_bg_file_list)
-    elif cstat_exe_name == 'pycbc_multiifo_add_statmap':
+    elif cstat_exe_name == 'pycbc_add_statmap':
         combine_statmap_node = cstat_exe.create_node(final_bg_file_list,
                                                      bg_file_list)
 
     workflow.add_node(combine_statmap_node)
     return combine_statmap_node.output_file
 
-def setup_multiifo_exclude_zerolag(workflow, statmap_file, other_statmap_files,
-                                   out_dir, ifos, tags=None):
+
+def setup_exclude_zerolag(workflow, statmap_file, other_statmap_files,
+                          out_dir, ifos, tags=None):
     """
     Exclude single triggers close to zerolag triggers from forming any
     background events
@@ -848,17 +574,18 @@ def setup_multiifo_exclude_zerolag(workflow, statmap_file, other_statmap_files,
     if tags is None:
         tags = []
     make_analysis_dir(out_dir)
-    logging.info('Setting up multiifo exclude zerolag')
+    logging.info('Setting up exclude zerolag')
 
-    exc_zerolag_exe = PyCBCMultiifoExcludeZerolag(workflow.cp, 'exclude_zerolag',
-                                                  ifos=ifos, tags=tags,
-                                                  out_dir=out_dir)
+    exc_zerolag_exe = PyCBCExcludeZerolag(workflow.cp, 'exclude_zerolag',
+                                          ifos=ifos, tags=tags,
+                                          out_dir=out_dir)
     exc_zerolag_node = exc_zerolag_exe.create_node(statmap_file,
                                                    other_statmap_files,
                                                    tags=None)
     workflow.add_node(exc_zerolag_node)
     return exc_zerolag_node.output_file
 
+
 def rerank_coinc_followup(workflow, statmap_file, bank_file, out_dir,
                           tags=None,
                           injection_file=None,
