@@ -444,6 +444,74 @@ def make_inference_acceptance_rate_plot(workflow, inference_file, output_dir,
     return node.output_files
 
 
+def make_inference_dynesty_run_plot(workflow, inference_file, output_dir,
+                                    name="plot_dynesty_run",
+                                    analysis_seg=None, tags=None):
+    """Sets up a debugging plot for the dynesty run (for Dynesty sampler).
+
+    Parameters
+    ----------
+    workflow: pycbc.workflow.Workflow
+        The core workflow instance we are populating
+    inference_file: pycbc.workflow.File
+        The file with posterior samples.
+    output_dir: str
+        The directory to store result plots and files.
+    name: str, optional
+        The name in the [executables] section of the configuration file
+        to use, and the section to read for additional arguments to pass to
+        the executable. Default is ``plot_acceptance_rate``.
+    analysis_segs: ligo.segments.Segment, optional
+       The segment this job encompasses. If None then use the total analysis
+       time from the workflow.
+    tags: list, optional
+        Tags to add to the inference executables.
+
+    Returns
+    -------
+    pycbc.workflow.FileList
+        A list of output files.
+    """
+    node = make_inference_plot(workflow, inference_file, output_dir,
+                               name, analysis_seg=analysis_seg, tags=tags,
+                               add_to_workflow=True)
+    return node.output_files
+
+
+def make_inference_dynesty_trace_plot(workflow, inference_file, output_dir,
+                                      name="plot_dynesty_traceplot",
+                                      analysis_seg=None, tags=None):
+    """Sets up a trace plot for the dynesty run (for Dynesty sampler).
+
+    Parameters
+    ----------
+    workflow: pycbc.workflow.Workflow
+        The core workflow instance we are populating
+    inference_file: pycbc.workflow.File
+        The file with posterior samples.
+    output_dir: str
+        The directory to store result plots and files.
+    name: str, optional
+        The name in the [executables] section of the configuration file
+        to use, and the section to read for additional arguments to pass to
+        the executable. Default is ``plot_acceptance_rate``.
+    analysis_segs: ligo.segments.Segment, optional
+       The segment this job encompasses. If None then use the total analysis
+       time from the workflow.
+    tags: list, optional
+        Tags to add to the inference executables.
+
+    Returns
+    -------
+    pycbc.workflow.FileList
+        A list of output files.
+    """
+    node = make_inference_plot(workflow, inference_file, output_dir,
+                               name, analysis_seg=analysis_seg, tags=tags,
+                               add_to_workflow=True)
+    return node.output_files
+
+
 def make_inference_pp_table(workflow, posterior_files, output_dir,
                             parameters=None, injection_samples_map=None,
                             name="pp_table_summary",
@@ -622,6 +690,10 @@ def get_diagnostic_plots(workflow):
         diagnostics.append('samples')
     if "plot_acceptance_rate" in workflow.cp.options("executables"):
         diagnostics.append('acceptance_rate')
+    if "plot_dynesty_run" in workflow.cp.options("executables"):
+        diagnostics.append('dynesty_run')
+    if "plot_dynesty_traceplot" in workflow.cp.options("executables"):
+        diagnostics.append('dynesty_traceplot')
     return diagnostics
 
 
@@ -688,6 +760,30 @@ def make_diagnostic_plots(workflow, diagnostics, samples_file, label, rdir,
         out['acceptance_rate'] = acceptance_plots
         layout.single_layout(rdir[base], acceptance_plots)
 
+    if 'dynesty_run' in diagnostics:
+        # files for dynesty run subsection
+        base = "dynesty_run/{}".format(label)
+        dynesty_run_plots = []
+        for kk, sf in enumerate(samples_file):
+            dynesty_run_plots += make_inference_dynesty_run_plot(
+                workflow, sf, rdir[base],
+                analysis_seg=workflow.analysis_time,
+                tags=tags+[label, str(kk)])
+        out['dynesty_run'] = dynesty_run_plots
+        layout.single_layout(rdir[base], dynesty_run_plots)
+
+    if 'dynesty_traceplot' in diagnostics:
+        # files for samples dynesty tyrace plots subsection
+        base = "dynesty_traceplot/{}".format(label)
+        dynesty_trace_plots = []
+        for kk, sf in enumerate(samples_file):
+            dynesty_trace_plots += make_inference_dynesty_trace_plot(
+                workflow, sf, rdir[base],
+                analysis_seg=workflow.analysis_time,
+                tags=tags+[label, str(kk)])
+        out['dynesty_traceplot'] = dynesty_trace_plots
+        layout.single_layout(rdir[base], dynesty_trace_plots)
+
     return out
 
 
